@@ -1,6 +1,7 @@
 # (c) 2016 Red Hat Inc.
 # (c) 2017 Ansible Project
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 
@@ -27,6 +28,7 @@ options:
       to.
     default: inventory_hostname
     vars:
+    - name: inventory_hostname
     - name: ansible_host
   port:
     type: int
@@ -109,6 +111,19 @@ options:
     - name: ansible_network_become_errors
     default: fail
     choices: ["ignore", "warn", "fail"]
+  terminal_errors:
+    type: str
+    description:
+    - This option determines how failures while setting terminal parameters
+      are handled.
+    - When set to C(ignore), the errors are silently ignored.
+      When set to C(warn), a warning message is displayed.
+      The default option C(fail), triggers a failure and halts execution.
+    vars:
+    - name: ansible_network_terminal_errors
+    default: fail
+    choices: ["ignore", "warn", "fail"]
+    version_added: 3.1.0
   become_method:
     description:
     - This option allows the become method to be specified in for handling privilege
@@ -122,24 +137,6 @@ options:
     - name: ANSIBLE_BECOME_METHOD
     vars:
     - name: ansible_become_method
-  import_modules:
-    type: boolean
-    description:
-    - Reduce CPU usage and network module execution time
-      by enabling direct execution. Instead of the module being packaged
-      and executed by the shell, it will be directly executed by the Ansible
-      control node using the same python interpreter as the Ansible process.
-      Note- Incompatible with C(asynchronous mode).
-      Note- Python 3 and Ansible 2.9.16 or greater required.
-      Note- With Ansible 2.9.x fully qualified modules names are required in tasks.
-    default: false
-    ini:
-    - section: ansible_network
-      key: import_modules
-    env:
-    - name: ANSIBLE_NETWORK_IMPORT_MODULES
-    vars:
-    - name: ansible_network_import_modules
   host_key_auto_add:
     type: boolean
     description:
@@ -196,6 +193,7 @@ options:
     - name: ansible_terminal_stderr_re
   terminal_initial_prompt:
     type: list
+    elements: string
     description:
     - A single regex pattern or a sequence of patterns to evaluate the expected prompt
       at the time of initial login to the remote host.
@@ -203,6 +201,7 @@ options:
     - name: ansible_terminal_initial_prompt
   terminal_initial_answer:
     type: list
+    elements: string
     description:
     - The answer to reply with if the C(terminal_initial_prompt) is matched. The value
       can be a single answer or a list of answers for multiple terminal_initial_prompt.
@@ -249,10 +248,12 @@ options:
     - name: ansible_network_cli_retries
   ssh_type:
     description:
-      - The type of the transport used by C(network_cli) connection plugin to connection to remote host.
-        Valid value is either I(paramiko) or I(libssh)
-      - In order to use I(libssh), the ansible-pylibssh package needs to be installed
-    default: paramiko
+      - The python package that will be used by the C(network_cli) connection plugin to create a SSH connection to remote host.
+      - I(libssh) will use the ansible-pylibssh package, which needs to be installed in order to work.
+      - I(paramiko) will instead use the paramiko package to manage the SSH connection.
+      - I(auto) will use ansible-pylibssh if that package is installed, otherwise will fallback to paramiko.
+    default: auto
+    choices: ["libssh", "paramiko", "auto"]
     env:
         - name: ANSIBLE_NETWORK_CLI_SSH_TYPE
     ini:
@@ -289,30 +290,33 @@ options:
     - name: ansible_network_single_user_mode
 """
 
-from functools import wraps
 import getpass
 import json
 import logging
-import re
 import os
+import re
 import signal
 import socket
 import time
 import traceback
+from functools import wraps
 from io import BytesIO
 
 from ansible.errors import AnsibleConnectionFailure, AnsibleError
+from ansible.module_utils._text import to_bytes, to_text
 from ansible.module_utils.basic import missing_required_lib
 from ansible.module_utils.six import PY3
 from ansible.module_utils.six.moves import cPickle
-from ansible.module_utils._text import to_bytes, to_text
 from ansible.playbook.play_context import PlayContext
 from ansible.plugins.loader import (
+    cache_loader,
     cliconf_loader,
-    terminal_loader,
     connection_loader,
+    terminal_loader,
+)
+from ansible_collections.ansible.netcommon.plugins.connection.libssh import (
+    HAS_PYLIBSSH,
 )
-from ansible.plugins.loader import cache_loader
 from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.utils import (
     to_list,
 )
@@ -412,27 +416,56 @@ class Connection(NetworkConnectionBase):
             )
         self.queue_message("log", "network_os is set to %s" % self._network_os)
 
+    @property
+    def ssh_type(self):
+        if self._ssh_type is None:
+            self._ssh_type = self.get_option("ssh_type")
+            self.queue_message(
+                "vvvv", "ssh type is set to %s" % self._ssh_type
+            )
+            # Support autodetection of supported library
+            if self._ssh_type == "auto":
+                self.queue_message("vvvv", "autodetecting ssh_type")
+                if HAS_PYLIBSSH:
+                    self._ssh_type = "libssh"
+                else:
+                    self.queue_message(
+                        "warning",
+                        "ansible-pylibssh not installed, falling back to paramiko",
+                    )
+                    self._ssh_type = "paramiko"
+                self.queue_message(
+                    "vvvv", "ssh type is now set to %s" % self._ssh_type
+                )
+
+        if self._ssh_type not in ["paramiko", "libssh"]:
+            raise AnsibleConnectionFailure(
+                "Invalid value '%s' set for ssh_type option."
+                " Expected value is either 'libssh' or 'paramiko'"
+                % self._ssh_type
+            )
+
+        return self._ssh_type
+
     @property
     def ssh_type_conn(self):
-        self._ssh_type = self.get_option("ssh_type")
         if self._ssh_type_conn is None:
-            if self._ssh_type not in ["paramiko", "libssh"]:
+            if self.ssh_type == "libssh":
+                connection_plugin = "ansible.netcommon.libssh"
+            elif self.ssh_type == "paramiko":
+                # NOTE: This MUST be paramiko or things will break
+                connection_plugin = "paramiko"
+            else:
                 raise AnsibleConnectionFailure(
                     "Invalid value '%s' set for ssh_type option."
                     " Expected value is either 'libssh' or 'paramiko'"
                     % self._ssh_type
                 )
 
-            # TODO: Remove this check if/when libssh connection plugin is moved to ansible-base
-            if self._ssh_type == "libssh":
-                self._ssh_type = "ansible.netcommon.libssh"
-
             self._ssh_type_conn = connection_loader.get(
-                self._ssh_type, self._play_context, "/dev/null"
-            )
-            self.queue_message(
-                "vvvv", "ssh type is set to %s" % self.get_option("ssh_type")
+                connection_plugin, self._play_context, "/dev/null"
             )
+
         return self._ssh_type_conn
 
     # To maintain backward compatibility
@@ -441,8 +474,17 @@ class Connection(NetworkConnectionBase):
         return self.ssh_type_conn
 
     def _get_log_channel(self):
-        name = "p=%s u=%s | " % (os.getpid(), getpass.getuser())
-        name += "%s [%s]" % (self._ssh_type, self._play_context.remote_addr)
+        user = ""
+        try:
+            user = getpass.getuser()
+        except KeyError:
+            self.queue_message(
+                "vv",
+                "Current user (uid=%s) does not seem to exist on this system, leaving user empty."
+                % os.getuid(),
+            )
+        name = "p=%s u=%s | " % (os.getpid(), user)
+        name += "%s [%s]" % (self.ssh_type, self._play_context.remote_addr)
         return name
 
     @ensure_connect
@@ -570,10 +612,10 @@ class Connection(NetworkConnectionBase):
         Connects to the remote device and starts the terminal
         """
         if self._play_context.verbosity > 3:
-            logging.getLogger(self._ssh_type).setLevel(logging.DEBUG)
+            logging.getLogger(self.ssh_type).setLevel(logging.DEBUG)
 
         self.queue_message(
-            "vvvv", "invoked shell using ssh_type: %s" % self._ssh_type
+            "vvvv", "invoked shell using ssh_type: %s" % self.ssh_type
         )
 
         self._single_user_mode = self.get_option("single_user_mode")
@@ -605,10 +647,14 @@ class Connection(NetworkConnectionBase):
                             to_text(e, errors="surrogate_or_strict")
                         )
                     else:
-                        msg = "network_cli_retry: attempt: %d, caught exception(%s), " "pausing for %d seconds" % (
-                            attempt + 1,
-                            to_text(e, errors="surrogate_or_strict"),
-                            pause,
+                        msg = (
+                            "network_cli_retry: attempt: %d, caught exception(%s), "
+                            "pausing for %d seconds"
+                            % (
+                                attempt + 1,
+                                to_text(e, errors="surrogate_or_strict"),
+                                pause,
+                            )
                         )
 
                         self.queue_message("vv", msg)
@@ -620,7 +666,7 @@ class Connection(NetworkConnectionBase):
             self._connected = True
 
             self._ssh_shell = ssh.ssh.invoke_shell()
-            if self._ssh_type == "paramiko":
+            if self.ssh_type == "paramiko":
                 self._ssh_shell.settimeout(command_timeout)
 
             self.queue_message(
@@ -657,7 +703,7 @@ class Connection(NetworkConnectionBase):
                 self._on_become(become_pass=auth_pass)
 
             self.queue_message("vvvv", "firing event: on_open_shell()")
-            self._terminal.on_open_shell()
+            self._on_open_shell()
 
             self.queue_message(
                 "vvvv", "ssh connection has completed successfully"
@@ -683,6 +729,25 @@ class Connection(NetworkConnectionBase):
             else:
                 raise
 
+    def _on_open_shell(self):
+        """
+        Wraps terminal.on_open_shell() to handle
+        terminal setting failures based on user preference
+        """
+        on_terminal_error = self.get_option("terminal_errors")
+        try:
+            self._terminal.on_open_shell()
+        except AnsibleConnectionFailure:
+            if on_terminal_error == "ignore":
+                pass
+            elif on_terminal_error == "warn":
+                self.queue_message(
+                    "warning",
+                    "on_open_shell: failed to set terminal parameters",
+                )
+            else:
+                raise
+
     def close(self):
         """
         Close the active connection to the device
@@ -719,7 +784,6 @@ class Connection(NetworkConnectionBase):
         check_all=False,
         strip_prompt=True,
     ):
-
         recv = BytesIO()
         cache_socket_timeout = self.get_option("persistent_command_timeout")
         self._ssh_shell.settimeout(cache_socket_timeout)
@@ -832,7 +896,6 @@ class Connection(NetworkConnectionBase):
         errored_response = None
 
         while True:
-
             if command_prompt_matched:
                 data = self._read_post_command_prompt_match()
                 if data:
@@ -891,7 +954,7 @@ class Connection(NetworkConnectionBase):
                 if errored_response:
                     raise AnsibleConnectionFailure(errored_response)
                 self._last_response = data
-                self._command_response += self._sanitize(
+                self._command_response = self._sanitize(
                     resp, command, strip_prompt
                 )
                 command_prompt_matched = True
@@ -935,7 +998,7 @@ class Connection(NetworkConnectionBase):
         )
 
         self._log_messages("command: %s" % command)
-        if self._ssh_type == "libssh":
+        if self.ssh_type == "libssh":
             response = self.receive_libssh(
                 command,
                 prompts,
@@ -945,7 +1008,7 @@ class Connection(NetworkConnectionBase):
                 check_all,
                 strip_prompt,
             )
-        else:
+        elif self.ssh_type == "paramiko":
             response = self.receive_paramiko(
                 command,
                 prompts,
@@ -1198,7 +1261,7 @@ class Connection(NetworkConnectionBase):
                         "'pattern' is a required key for option '%s',"
                         " received option value is %s" % (option, item)
                     )
-                pattern = br"%s" % to_bytes(item["pattern"])
+                pattern = rb"%s" % to_bytes(item["pattern"])
                 flag = item.get("flags", 0)
                 if flag:
                     flag = getattr(re, flag.split(".")[1])
@@ -1222,11 +1285,10 @@ class Connection(NetworkConnectionBase):
                         remote host before triggering timeout exception
         :return: None
         """
-        ssh_type = self.get_option("ssh_type")
         ssh = self.ssh_type_conn._connect_uncached()
-        if ssh_type == "libssh":
+        if self.ssh_type == "libssh":
             self.ssh_type_conn.put_file(source, destination, proto=proto)
-        elif ssh_type == "paramiko":
+        elif self.ssh_type == "paramiko":
             if proto == "scp":
                 if not HAS_SCP:
                     raise AnsibleError(missing_required_lib("scp"))
@@ -1244,7 +1306,7 @@ class Connection(NetworkConnectionBase):
                 )
         else:
             raise AnsibleError(
-                "Do not know how to do SCP with ssh_type %s" % ssh_type
+                "Do not know how to do SCP with ssh_type %s" % self.ssh_type
             )
 
     def get_file(self, source=None, destination=None, proto="scp", timeout=30):
@@ -1258,11 +1320,10 @@ class Connection(NetworkConnectionBase):
         :return: None
         """
         """Fetch file over scp/sftp from remote device"""
-        ssh_type = self.get_option("ssh_type")
         ssh = self.ssh_type_conn._connect_uncached()
-        if ssh_type == "libssh":
+        if self.ssh_type == "libssh":
             self.ssh_type_conn.fetch_file(source, destination, proto=proto)
-        elif ssh_type == "paramiko":
+        elif self.ssh_type == "paramiko":
             if proto == "scp":
                 if not HAS_SCP:
                     raise AnsibleError(missing_required_lib("scp"))
@@ -1284,7 +1345,7 @@ class Connection(NetworkConnectionBase):
                 )
         else:
             raise AnsibleError(
-                "Do not know how to do SCP with ssh_type %s" % ssh_type
+                "Do not know how to do SCP with ssh_type %s" % self.ssh_type
             )
 
     def get_cache(self):
