@@ -17,6 +17,12 @@ short_description: Add or remove Jenkins plugin
 description:
   - Ansible module which helps to manage Jenkins plugins.
 
+attributes:
+  check_mode:
+    support: full
+  diff_mode:
+    support: none
+
 options:
   group:
     type: str
@@ -47,7 +53,7 @@ options:
     type: str
     description:
       - Desired plugin state.
-      - If the C(latest) is set, the check for new version will be performed
+      - If set to V(latest), the check for new version will be performed
         every time. This is suitable to keep the plugin up-to-date.
     choices: [absent, present, pinned, unpinned, enabled, disabled, latest]
     default: present
@@ -59,18 +65,18 @@ options:
   updates_expiration:
     type: int
     description:
-      - Number of seconds after which a new copy of the I(update-center.json)
+      - Number of seconds after which a new copy of the C(update-center.json)
         file is downloaded. This is used to avoid the need to download the
-        plugin to calculate its checksum when C(latest) is specified.
-      - Set it to C(0) if no cache file should be used. In that case, the
+        plugin to calculate its checksum when O(state=latest) is specified.
+      - Set it to V(0) if no cache file should be used. In that case, the
         plugin file will always be downloaded to calculate its checksum when
-        C(latest) is specified.
+        O(state=latest) is specified.
     default: 86400
   updates_url:
     type: list
     elements: str
     description:
-      - A list of base URL(s) to retrieve I(update-center.json), and direct plugin files from.
+      - A list of base URL(s) to retrieve C(update-center.json), and direct plugin files from.
       - This can be a list since community.general 3.3.0.
     default: ['https://updates.jenkins.io', 'http://mirrors.jenkins.io']
   update_json_url_segment:
@@ -84,14 +90,14 @@ options:
     type: list
     elements: str
     description:
-      - Path inside the I(updates_url) to get latest plugins from.
+      - Path inside the O(updates_url) to get latest plugins from.
     default: ['latest']
     version_added: 3.3.0
   versioned_plugins_url_segments:
     type: list
     elements: str
     description:
-      - Path inside the I(updates_url) to get specific version of plugins from.
+      - Path inside the O(updates_url) to get specific version of plugins from.
     default: ['download/plugins', 'plugins']
     version_added: 3.3.0
   url:
@@ -108,11 +114,11 @@ options:
       - It might take longer to verify that the correct version is installed.
         This is especially true if a specific version number is specified.
       - Quote the version to prevent the value to be interpreted as float. For
-        example if C(1.20) would be unquoted, it would become C(1.2).
+        example if V(1.20) would be unquoted, it would become V(1.2).
   with_dependencies:
     description:
       - Defines whether to install plugin dependencies.
-      - This option takes effect only if the I(version) is not defined.
+      - This option takes effect only if the O(version) is not defined.
     type: bool
     default: true
 
@@ -121,16 +127,17 @@ notes:
     the plugin files on the disk. Only if the plugin is not installed yet and
     no version is specified, the API installation is performed which requires
     only the Web UI credentials.
-  - It's necessary to notify the handler or call the I(service) module to
+  - It is necessary to notify the handler or call the M(ansible.builtin.service) module to
     restart the Jenkins service after a new plugin was installed.
   - Pinning works only if the plugin is installed and Jenkins service was
     successfully restarted after the plugin installation.
-  - It is not possible to run the module remotely by changing the I(url)
+  - It is not possible to run the module remotely by changing the O(url)
     parameter to point to the Jenkins server. The module must be used on the
     host where Jenkins runs as it needs direct access to the plugin files.
 extends_documentation_fragment:
-  - url
-  - files
+  - ansible.builtin.url
+  - ansible.builtin.files
+  - community.general.attributes
 '''
 
 EXAMPLES = '''
@@ -295,7 +302,6 @@ import io
 import json
 import os
 import tempfile
-import time
 
 from ansible.module_utils.basic import AnsibleModule, to_bytes
 from ansible.module_utils.six.moves import http_cookiejar as cookiejar
@@ -635,6 +641,8 @@ class JenkinsPlugin(object):
                 self.module.fail_json(
                     msg="Cannot close the tmp updates file %s." % tmp_updates_file,
                     details=to_native(e))
+        else:
+            tmp_updates_file = updates_file
 
         # Open the updates file
         try:
@@ -645,15 +653,15 @@ class JenkinsPlugin(object):
             data = json.loads(f.readline())
         except IOError as e:
             self.module.fail_json(
-                msg="Cannot open temporal updates file.",
+                msg="Cannot open%s updates file." % (" temporary" if tmp_updates_file != updates_file else ""),
                 details=to_native(e))
         except Exception as e:
             self.module.fail_json(
-                msg="Cannot load JSON data from the tmp updates file.",
+                msg="Cannot load JSON data from the%s updates file." % (" temporary" if tmp_updates_file != updates_file else ""),
                 details=to_native(e))
 
         # Move the updates file to the right place if we could read it
-        if download_updates:
+        if tmp_updates_file != updates_file:
             self.module.atomic_move(tmp_updates_file, updates_file)
 
         # Check if we have the plugin data available
