@@ -53,7 +53,7 @@ options:
       - Append the privileges defined by the I(priv) option to the existing ones
         for this role instead of overwriting them. Mutually exclusive with I(subtract_privs).
     type: bool
-    default: no
+    default: false
 
   subtract_privs:
     description:
@@ -62,7 +62,7 @@ options:
         Mutually exclusive with I(append_privs).
     version_added: '3.2.0'
     type: bool
-    default: no
+    default: false
 
   members:
     description:
@@ -80,7 +80,7 @@ options:
         for this role instead of overwriting them.
       - Mutually exclusive with the I(detach_members) and I(admin) option.
     type: bool
-    default: no
+    default: false
 
   detach_members:
     description:
@@ -88,7 +88,7 @@ options:
         instead of overwriting all the current members.
       - Mutually exclusive with the I(append_members) and I(admin) option.
     type: bool
-    default: no
+    default: false
 
   set_default_role_all:
     description:
@@ -96,7 +96,7 @@ options:
       - If C(yes), runs B(SET DEFAULT ROLE ALL TO) each of the I(members) when changed.
       - If you want to avoid this behavior, set this option to C(no) explicitly.
     type: bool
-    default: yes
+    default: true
 
   state:
     description:
@@ -112,7 +112,14 @@ options:
       - Check if mysql allows login as root/nopassword before trying supplied credentials.
       - If success, passed I(login_user)/I(login_password) will be ignored.
     type: bool
-    default: no
+    default: false
+
+  members_must_exist:
+    description:
+      - When C(yes), the module fails if any user in I(members) does not exist.
+      - When C(no), users in I(members) which don't exist are simply skipped.
+    type: bool
+    default: true
 
 notes:
   - Pay attention that the module runs C(SET DEFAULT ROLE ALL TO)
@@ -128,12 +135,16 @@ seealso:
 
 author:
   - Andrew Klychkov (@Andersson007)
+  - Felix Hamme (@betanummeric)
 
 extends_documentation_fragment:
   - community.mysql.mysql
 '''
 
 EXAMPLES = r'''
+# If you encounter the "Please explicitly state intended protocol" error,
+# use the login_unix_socket argument, for example, login_unix_socket: /run/mysqld/mysqld.sock
+
 # Example of a .my.cnf file content for setting a root password
 # [client]
 # user=root
@@ -170,7 +181,7 @@ EXAMPLES = r'''
     members:
     - 'alice@%'
     - 'bob@%'
-    set_default_role_all: no
+    set_default_role_all: false
 
 # Assuming that the role developers exists,
 # add john to the current members
@@ -178,7 +189,7 @@ EXAMPLES = r'''
   community.mysql.mysql_role:
     name: developers
     state: present
-    append_members: yes
+    append_members: true
     members:
     - 'joe@localhost'
 
@@ -197,7 +208,7 @@ EXAMPLES = r'''
     name: readers
     state: present
     priv: 'fiction.*:UPDATE'
-    append_privs: yes
+    append_privs: true
 
 - name: Create role with the 'SELECT' and 'UPDATE' privileges in db1 and db2
   community.mysql.mysql_role:
@@ -213,7 +224,7 @@ EXAMPLES = r'''
     name: readers
     members:
     - 'joe@localhost'
-    detach_members: yes
+    detach_members: true
 
 - name: Remove the role readers if exists
   community.mysql.mysql_role:
@@ -247,9 +258,29 @@ EXAMPLES = r'''
   community.mysql.mysql_role:
     state: present
     name: foo
-    subtract_privs: yes
+    subtract_privs: true
     priv:
       'db1.*': DELETE
+
+- name: Add some members to a role and skip not-existent users
+  community.mysql.mysql_role:
+    state: present
+    name: foo
+    append_members: true
+    members_must_exist: false
+    members:
+    - 'existing_user@localhost'
+    - 'not_existing_user@localhost'
+
+- name: Detach some members from a role and ignore not-existent users
+  community.mysql.mysql_role:
+    state: present
+    name: foo
+    detach_members: true
+    members_must_exist: false
+    members:
+    - 'existing_user@localhost'
+    - 'not_existing_user@localhost'
 '''
 
 RETURN = '''#'''
@@ -381,6 +412,11 @@ class DbServer():
                 msg = 'User / role `%s` with host `%s` does not exist' % (user[0], user[1])
                 self.module.fail_json(msg=msg)
 
+    def filter_existing_users(self, users):
+        for user in users:
+            if user in self.users:
+                yield user
+
     def __get_users(self):
         """Get users.
 
@@ -878,10 +914,11 @@ class Role():
                                                       set_default_role_all=set_default_role_all)
 
         if privs:
-            changed, msg = user_mod(self.cursor, self.name, self.host,
-                                    None, None, None, None, None, None,
-                                    privs, append_privs, subtract_privs, None,
-                                    self.module, role=True, maria_role=self.is_mariadb)
+            result = user_mod(self.cursor, self.name, self.host,
+                              None, None, None, None, None, None,
+                              privs, append_privs, subtract_privs, None,
+                              self.module, role=True, maria_role=self.is_mariadb)
+            changed = result['changed']
 
         if admin:
             self.role_impl.set_admin(admin)
@@ -896,50 +933,11 @@ class Role():
         Returns:
             set: Members.
         """
-        members = set()
-
-        for user, host in self.server.get_users():
-            # Don't handle itself
-            if user == self.name and host == self.host:
-                continue
-
-            grants = self.server.get_grants(user, host)
-
-            if self.__is_member(grants):
-                members.add((user, host))
-
-        return members
-
-    def __is_member(self, grants):
-        """Check if a user / role is a member of a role.
-
-        To check if a user is a member of a role,
-        we parse their grants looking for the role name in them.
-        In the following grants, we can see that test@% is a member of readers.
-        +---------------------------------------------------+
-        | Grants for test@%                                 |
-        +---------------------------------------------------+
-        | GRANT SELECT, INSERT, UPDATE ON *.* TO `test`@`%` |
-        | GRANT ALL PRIVILEGES ON `mysql`.* TO `test`@`%`   |
-        | GRANT INSERT ON `mysql`.`user` TO `test`@`%`      |
-        | GRANT `readers`@`%` TO `test`@`%`                 |
-        +---------------------------------------------------+
-
-        Args:
-            grants (list): Grants of a user to parse.
-
-        Returns:
-            bool: True if the self.full_name has been found in grants,
-                otherwise returns False.
-        """
-        if not grants:
-            return False
-
-        for grant in grants:
-            if self.full_name in grant[0]:
-                return True
-
-        return False
+        if self.is_mariadb:
+            self.cursor.execute('select user, host from mysql.roles_mapping where role = %s', (self.name,))
+        else:
+            self.cursor.execute('select TO_USER as user, TO_HOST as host from mysql.role_edges where FROM_USER = %s', (self.name,))
+        return set(self.cursor.fetchall())
 
 
 def main():
@@ -956,6 +954,7 @@ def main():
         detach_members=dict(type='bool', default=False),
         check_implicit_admin=dict(type='bool', default=False),
         set_default_role_all=dict(type='bool', default=True),
+        members_must_exist=dict(type='bool', default=True)
     )
     module = AnsibleModule(
         argument_spec=argument_spec,
@@ -989,6 +988,7 @@ def main():
     check_hostname = module.params['check_hostname']
     db = ''
     set_default_role_all = module.params['set_default_role_all']
+    members_must_exist = module.params['members_must_exist']
 
     if priv and not isinstance(priv, (str, dict)):
         msg = ('The "priv" parameter must be str or dict '
@@ -1008,7 +1008,8 @@ def main():
                 cursor, db_conn = mysql_connect(module, 'root', '', config_file,
                                                 ssl_cert, ssl_key, ssl_ca, db,
                                                 connect_timeout=connect_timeout,
-                                                check_hostname=check_hostname)
+                                                check_hostname=check_hostname,
+                                                autocommit=True)
             except Exception:
                 pass
 
@@ -1016,7 +1017,8 @@ def main():
             cursor, db_conn = mysql_connect(module, login_user, login_password,
                                             config_file, ssl_cert, ssl_key,
                                             ssl_ca, db, connect_timeout=connect_timeout,
-                                            check_hostname=check_hostname)
+                                            check_hostname=check_hostname,
+                                            autocommit=True)
 
     except Exception as e:
         module.fail_json(msg='unable to connect to database, '
@@ -1057,7 +1059,10 @@ def main():
 
     if members:
         members = normalize_users(module, members, server.is_mariadb())
-        server.check_users_in_db(members)
+        if members_must_exist:
+            server.check_users_in_db(members)
+        else:
+            members = list(server.filter_existing_users(members))
 
     # Main job starts here
     role = Role(module, cursor, name, server)
@@ -1067,6 +1072,8 @@ def main():
             if not role.exists:
                 if subtract_privs:
                     priv = None  # avoid granting unwanted privileges
+                if detach_members:
+                    members = None  # avoid adding unwanted members
                 changed = role.add(members, priv, module.check_mode, admin,
                                    set_default_role_all)
 
